# EpyNN - Changelog

## Past releases

### 1.0 - Initial release

* **epynn** contains core API sources and related to https://epynn.net/.
* **dpynn** contains developmental API sources.
* **epynnlive** contains live examples in Python and Jupyter notebook formats.
* https://epynn.net/ contains extensive documentation.

**1.0.4**

* Change positive and negative label assignment in ``epynnlive`` examples.

**1.0.3**

* Regression in ``epynn.network.embedding.models.Embedding``, remove ``XY_encode`` argument.

**1.0.2**

* Patch *KeyError* exception from ``epynn.network.hyperparameters.model_hyperparameters()`` that arised when assigning layer-specific hyperparameters.

**1.0.1**

* Change **nnlibs** to **epynn**.
* Implement **dpynn**.
